package com.fidms.web.mapper;

import java.util.List;
import com.fidms.web.domain.InfraredOutput;

/**
 * 红外输出Mapper接口
 * 
 * @author Allen
 * @date 2023-05-08
 */
public interface InfraredOutputMapper 
{
    /**
     * 查询红外输出
     * 
     * @param id 红外输出主键
     * @return 红外输出
     */
    public InfraredOutput selectInfraredOutputById(Long id);

    /**
     * 查询红外输出列表
     * 
     * @param infraredOutput 红外输出
     * @return 红外输出集合
     */
    public List<InfraredOutput> selectInfraredOutputList(InfraredOutput infraredOutput);

    /**
     * 新增红外输出
     * 
     * @param infraredOutput 红外输出
     * @return 结果
     */
    public int insertInfraredOutput(InfraredOutput infraredOutput);

    /**
     * 修改红外输出
     * 
     * @param infraredOutput 红外输出
     * @return 结果
     */
    public int updateInfraredOutput(InfraredOutput infraredOutput);

    /**
     * 删除红外输出
     * 
     * @param id 红外输出主键
     * @return 结果
     */
    public int deleteInfraredOutputById(Long id);

    /**
     * 批量删除红外输出
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteInfraredOutputByIds(Long[] ids);
}
